==> spirit_hub-0.0.1.0.tar.gz: spirit_hub-0.0.1.0/app/controllers/spirit_hub/tagsets_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class TagsetsController < ApplicationController
    def logs
      skip_authorization
      skip_policy_scope

      @tagset = Tagset.find(params[:id])
      @logs = @tagset.logs

      respond_to(&:html)
    end

    def doc
      skip_authorization
      skip_policy_scope

      @tagset = Tagset.find(params[:id])
      @logs = @tagset.logs
      @doc = @tagset.docs.first

      respond_to(&:html)
    end

    def add_doc_form
      skip_authorization
      skip_policy_scope

      @tagsets = Tagset.where(type: 'directory').order_by(updated_at: :desc).limit(5)

      render turbo_stream: [
        turbo_stream.update(:modal, partial: 'spirit_hub/tagsets/add_doc_form', locals: { form_url: add_doc_spirit_hub_tagsets_path })
      ]
    end

    def add_doc
      skip_authorization
      skip_policy_scope

      @model = Tagset.create_tagset_doc_from_file(params[:file], @user)
      @model.add_tagset_doc_to_object(params[:tagset_id])
      @model.reload

      flash.now[:notice] = 'Documents ajouté'
      turbo_actions = [turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')]

      referer_route = route_from_referer(request.referer)
      turbo_actions.concat(turbo_action_for_add_doc(referer_route)) if referer_route

      render turbo_stream: turbo_actions
    end

    def share_form
      skip_authorization
      skip_policy_scope

      @model = Tagset.find(params[:id])

      render turbo_stream: [
        turbo_stream.update(:modal, partial: 'spirit_hub/tagsets/share_form')
      ]
    end

    def share
      skip_authorization
      skip_policy_scope

      @model = Tagset.find(params[:id])
      @model.share_to_users(params[:to], params[:cc], params[:bcc], @user)

      flash.now[:notice] = 'Document partagé'

      render turbo_stream: [
        turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
        turbo_stream.replace("informed_badges_#{@model.id}", partial: 'spirit_hub/common/informed_badges', locals: { model: @model })
      ]
    end

    def search_directories
      skip_authorization
      skip_policy_scope

      @tagsets = Tagset.where(type: 'directory', :operation_id.ne => nil, title: /#{Regexp.escape(params[:query]).accent_to_regexp}/i).order_by(updated_at: :desc).limit(5)

      respond_to do |format|
        format.turbo_stream do
          render turbo_stream: [
            turbo_stream.replace(:directory_selector, partial: 'spirit_hub/tagsets/directory_selector', locals: { tagsets: @tagsets })
          ]
        end
      end
    end

    def add_favorite
      skip_authorization
      skip_policy_scope

      @model = Tagset.find(params[:id])

      if Favorite.create(user: @user, tagset: @model)
        set_user_favorites
        flash.now[:notice] = 'Ajouté aux favoris'

        render turbo_stream: [
          turbo_stream.replace("add_remove_favorites_#{@model.id}", partial: 'spirit_hub/common/add_remove_favorites', locals: { model: @model }),
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      else
        flash.now[:alert] = 'Erreur lors de l\'ajout au favoris'

        render turbo_stream: [
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      end
    end

    def remove_favorite
      skip_authorization
      skip_policy_scope

      @model = Tagset.find(params[:id])

      if Favorite.where(user: @user, tagset: @model).destroy_all
        set_user_favorites
        flash.now[:notice] = 'Supprimé des favoris'

        render turbo_stream: [
          turbo_stream.replace("add_remove_favorites_#{@model.id}", partial: 'spirit_hub/common/add_remove_favorites', locals: { model: @model }),
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      else
        flash.now[:alert] = 'Erreur lors de l\'ajout au favoris'

        render turbo_stream: [
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      end
    end

    def delete_item
      skip_authorization
      skip_policy_scope

      @model = Tagset.find(params[:id])

      success_message = @model.doc? ? 'Document supprimé' : 'Dossier supprimé'

      @model.current_user_id = @user.id

      if @model.destroy
        flash.now[:notice] = success_message

        render turbo_stream: [
          turbo_stream.remove("tagset_#{params[:id]}"),
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
          turbo_stream.custom_action(:change_counter, target: :end_index, attributes: { amount: -1 })
        ]
      else
        flash.now[:alert] = 'Erreur lors de la suppresion'

        render turbo_stream: [
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      end
    end

    def bulk_delete
      skip_authorization
      skip_policy_scope

      ids = params[:ids].split(',')

      Tagset.where(:id.in => ids).each do |tagset|
        tagset.current_user_id = @user.id
        tagset.destroy
      end

      flash.now[:notice] = 'Documents supprimés'

      render turbo_stream: [
        *ids.map { |id| turbo_stream.remove("tagset_#{id}") },
        turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
        turbo_stream.custom_action(:change_counter, target: :end_index, attributes: { amount: -ids.length })
      ]
    end

    private

    def share_params
      permitted_params = params.permit(:to, :cc, :bcc)

      permitted_params.each do |k, v|
        permitted_params[k] = v.reject(&:blank?)
      end

      permitted_params
    end

    def turbo_action_for_add_doc(referer_route)
      case referer_route[:controller]
      when 'spirit_hub/favorites'
        @counts = @user.dashboard_counts
        [turbo_stream.replace('favorites-counts', partial: 'spirit_hub/favorites/counts', formats: [:html])]
      when 'spirit_hub/todos'
        handle_todos_add_doc
      when 'spirit_hub/to_categorizes'
        handle_to_categorizes_add_doc
      else
        []
      end
    end

    def handle_todos_add_doc
      return [] if !@model.parent_tagset_ids || @model.parent_tagset_ids.empty?

      # TODO : Refactor this
      referer_controller = SpiritHub::TodosController.new
      referer_controller.instance_variable_set(:@user, @user)
      referer_controller.set_columns
      @user_column_names = referer_controller.instance_variable_get(:@user_column_names)
      @user_favorites = []

      partial = referer_controller.set_view_type == 'table' ? 'spirit_hub/todos/row' : 'spirit_hub/todos/card'
      [turbo_stream.prepend('todos-table-body', partial:, formats: [:html], locals: { model: @model })]
    end

    def handle_to_categorizes_add_doc
      return [] unless @model.parent_tagset_ids && @model.parent_tagset_ids.empty?

      # TODO : Refactor this
      referer_controller = SpiritHub::TodosController.new
      referer_controller.instance_variable_set(:@user, @user)
      referer_controller.set_columns
      @user_column_names = referer_controller.instance_variable_get(:@user_column_names)
      @user_favorites = []

      partial = referer_controller.set_view_type == 'table' ? 'spirit_hub/to_categorizes/row' : 'spirit_hub/to_categorizes/card'
      [turbo_stream.prepend('to-categorize-table-body', partial:, formats: [:html], locals: { model: @model })]
    end
  end
end

==> spirit_hub-0.0.1.4.tar.gz: spirit_hub-0.0.1.4/app/controllers/spirit_hub/tagsets_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class TagsetsController < ApplicationController
    def logs
      skip_authorization
      skip_policy_scope

      @tagset = Tagset.find(params[:id])
      @logs = @tagset.logs

      respond_to(&:html)
    end

    def doc
      skip_authorization
      skip_policy_scope

      @tagset = Tagset.find(params[:id])
      @logs = @tagset.logs
      @doc = @tagset.docs.find_by(id: params[:doc_id])

      respond_to(&:html)
    end

    def add_doc_form
      skip_authorization
      skip_policy_scope

      @tagsets = Tagset.where(type: 'directory').order_by(updated_at: :desc).limit(5)

      render turbo_stream: [
        turbo_stream.update(:modal, partial: 'spirit_hub/tagsets/add_doc_form', locals: { form_url: add_doc_spirit_hub_tagsets_path })
      ]
    end

    def add_doc
      skip_authorization
      skip_policy_scope

      @model = Tagset.create_tagset_doc_from_file(params[:files], @user)
      @model.add_tagset_doc_to_object(params[:tagset_id])
      @model.reload

      flash.now[:notice] = 'Documents ajouté'
      turbo_actions = [turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')]

      referer_route = route_from_referer(request.referer)
      turbo_actions.concat(turbo_action_for_add_doc(referer_route)) if referer_route

      render turbo_stream: turbo_actions
    end

    def share_form
      skip_authorization
      skip_policy_scope

      @model = Tagset.find(params[:id])

      render turbo_stream: [
        turbo_stream.update(:modal, partial: 'spirit_hub/tagsets/share_form')
      ]
    end

    def share
      skip_authorization
      skip_policy_scope

      @model = Tagset.find(params[:id])
      @model.share_to_users(params[:to], params[:cc], params[:bcc], @user)

      flash.now[:notice] = 'Document partagé'

      render turbo_stream: [
        turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
        turbo_stream.replace("informed_badges_#{@model.id}", partial: 'spirit_hub/common/informed_badges', locals: { model: @model })
      ]
    end

    def search_directories
      skip_authorization
      skip_policy_scope

      @tagsets = Tagset.where(type: 'directory', :operation_id.ne => nil, title: /#{Regexp.escape(params[:query]).accent_to_regexp}/i).order_by(updated_at: :desc).limit(5)

      respond_to do |format|
        format.turbo_stream do
          render turbo_stream: [
            turbo_stream.replace(:directory_selector, partial: 'spirit_hub/tagsets/directory_selector', locals: { tagsets: @tagsets })
          ]
        end
      end
    end

    def add_favorite
      skip_authorization
      skip_policy_scope

      @model = Tagset.find(params[:id])

      if Favorite.create(user: @user, tagset: @model)
        set_user_favorites
        flash.now[:notice] = 'Ajouté aux favoris'

        render turbo_stream: [
          turbo_stream.replace("add_remove_favorites_#{@model.id}", partial: 'spirit_hub/common/add_remove_favorites', locals: { model: @model }),
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      else
        flash.now[:alert] = 'Erreur lors de l\'ajout au favoris'

        render turbo_stream: [
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      end
    end

    def remove_favorite
      skip_authorization
      skip_policy_scope

      @model = Tagset.find(params[:id])

      if Favorite.where(user: @user, tagset: @model).destroy_all
        set_user_favorites
        flash.now[:notice] = 'Supprimé des favoris'

        render turbo_stream: [
          turbo_stream.replace("add_remove_favorites_#{@model.id}", partial: 'spirit_hub/common/add_remove_favorites', locals: { model: @model }),
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      else
        flash.now[:alert] = 'Erreur lors de l\'ajout au favoris'

        render turbo_stream: [
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      end
    end

    def delete_item
      skip_authorization
      skip_policy_scope

      @model = Tagset.find(params[:id])

      success_message = @model.doc? ? 'Document supprimé' : 'Dossier supprimé'

      @model.current_user_id = @user.id

      if @model.destroy
        flash.now[:notice] = success_message

        render turbo_stream: [
          turbo_stream.remove("tagset_#{params[:id]}"),
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
          turbo_stream.custom_action(:change_counter, target: :end_index, attributes: { amount: -1 })
        ]
      else
        flash.now[:alert] = 'Erreur lors de la suppresion'

        render turbo_stream: [
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      end
    end

    def bulk_delete
      skip_authorization
      skip_policy_scope

      ids = params[:ids].split(',')

      Tagset.where(:id.in => ids).each do |tagset|
        tagset.current_user_id = @user.id
        tagset.destroy
      end

      flash.now[:notice] = 'Documents supprimés'

      render turbo_stream: [
        *ids.map { |id| turbo_stream.remove("tagset_#{id}") },
        turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
        turbo_stream.custom_action(:change_counter, target: :end_index, attributes: { amount: -ids.length })
      ]
    end

    private

    def share_params
      permitted_params = params.permit(:to, :cc, :bcc)

      permitted_params.each do |k, v|
        permitted_params[k] = v.reject(&:blank?)
      end

      permitted_params
    end

    def turbo_action_for_add_doc(referer_route)
      case referer_route[:controller]
      when 'spirit_hub/favorites'
        @counts = @user.dashboard_counts
        [turbo_stream.replace('favorites-counts', partial: 'spirit_hub/favorites/counts', formats: [:html])]
      when 'spirit_hub/todos'
        handle_todos_add_doc
      when 'spirit_hub/to_categorizes'
        handle_to_categorizes_add_doc
      else
        []
      end
    end

    def handle_todos_add_doc
      return [] if !@model.parent_tagset_ids || @model.parent_tagset_ids.empty?

      # TODO : Refactor this
      referer_controller = SpiritHub::TodosController.new
      referer_controller.instance_variable_set(:@user, @user)
      referer_controller.set_columns
      @user_column_names = referer_controller.instance_variable_get(:@user_column_names)
      @user_favorites = []

      partial = referer_controller.set_view_type == 'table' ? 'spirit_hub/todos/row' : 'spirit_hub/todos/card'
      [turbo_stream.prepend('todos-table-body', partial:, formats: [:html], locals: { model: @model })]
    end

    def handle_to_categorizes_add_doc
      return [] unless @model.parent_tagset_ids && @model.parent_tagset_ids.empty?

      # TODO : Refactor this
      referer_controller = SpiritHub::TodosController.new
      referer_controller.instance_variable_set(:@user, @user)
      referer_controller.set_columns
      @user_column_names = referer_controller.instance_variable_get(:@user_column_names)
      @user_favorites = []

      partial = referer_controller.set_view_type == 'table' ? 'spirit_hub/to_categorizes/row' : 'spirit_hub/to_categorizes/card'
      [turbo_stream.prepend('to-categorize-table-body', partial:, formats: [:html], locals: { model: @model })]
    end
  end
end
